
"""
$Id: testAttributePropertyAdapter.py,v 1.2 2003/05/21 00:04:00 philipp Exp $
"""

import os, sys
if __name__ == '__main__':
    execfile(os.path.join(sys.path[0], 'framework.py'))

from Testing import ZopeTestCase
from Products.RevisionManager.Properties import AttributePropertyAdapter
from Products.RevisionManager.interfaces.Properties import IPropertyAdapter

ZopeTestCase.installProduct('RevisionManager')

class PropertyContainer:

    def __init__(self):
        self.foo = 'foo'
        self.bar = 2
        self.baz = 4.5
        self.should_not_appear = 1

class AttributePropertyAdapterTest(ZopeTestCase.ZopeTestCase):

    def afterSetUp(self):
        self.adapter = AttributePropertyAdapter(['foo', 'bar', 'baz'])
        self.propcontainer = PropertyContainer()

    def afterClear(self):
        pass

    def test_verify_interface(self):
        """Verify interface implementation"""
        from Interface.Verify import verifyClass
        self.failUnless(verifyClass(IPropertyAdapter,
                                    AttributePropertyAdapter))

    def test_get_properties(self):
        """Test getProperties()"""
        adapter = self.adapter
        propcontainer = self.propcontainer
        expected = (
            {'id':'foo', 'value': 'foo', 'type':'string'},
            {'id':'bar', 'value': 2,     'type':'int'},
            {'id':'baz', 'value': 4.5,   'type':'float'}
            )
        result = adapter.getProperties(propcontainer)
        self.assertEqual(expected, result)

    def test_set_properties(self):
        """Test setProperties()"""
        adapter = self.adapter
        propcontainer = self.propcontainer
        properties = (
            {'id':'baz', 'value': 'foo', 'type':'string'},
            {'id':'foo', 'value': 2,     'type':'int'},
            {'id':'bar', 'value': 4.5,   'type':'float'}
            )
        adapter.setProperties(propcontainer, properties)
        self.assertEqual(propcontainer.baz, 'foo')
        self.assertEqual(propcontainer.foo, 2)
        self.assertEqual(propcontainer.bar, 4.5)

        # supply less information
        properties = (
            {'id':'baz', 'value': 'foo', 'type':'string'},
            {'id':'foo', 'value': 2,     'type':'int'},
            )
        adapter.setProperties(propcontainer, properties)
        self.failIf(hasattr(propcontainer, 'bar'))

        # supply more information
        properties = (
            {'id':'baz', 'value': 'foo', 'type':'string'},
            {'id':'foo', 'value': 2,     'type':'int'},
            {'id':'bar', 'value': 4.5,   'type':'float'},
            {'id':'bad', 'value': 'bad', 'type':'string'}
            )
        adapter.setProperties(propcontainer, properties)
        self.failIf(hasattr(propcontainer, 'bad'))

if __name__ == '__main__':
    framework(descriptions=1, verbosity=2)
else:
    import unittest
    def test_suite():
        suite = unittest.TestSuite()
        suite.addTest(unittest.makeSuite(AttributePropertyAdapterTest))
        return suite

